function llclineviewer(y1,y2,P);

% LLCLINEVIEWER -- Interpolate between two clicked points linearly.
%
% P should be a structure with:
%
%   hh          handle to image object where images are shown.
%
%   snap        1 if points snap to closest data points. 0 otherwise.
%   dims        [d1 d2] corresponding to dimension of x,y axes in finder.
%   idims       dimensions along which to do interpolation.
%
%   imsize      size of images (prod(imsize)=DD).
%   numim       number of interpolants (including end points).
%   numrep      nuber of repeats for animation.
%   montage     1 if interpolants shown as horizontal montage. 0 for animation.
%   crange      Range of pixel intensities for images.
%
%   XX,YY,LX,MX,PX,Pi,LY,MY     Data and parameters used/produced by LLC.
%   PY          Given error variance for YY (I use 1e-3*ones(dd,1)).

dims  = P.dims;
idims = P.idims;
if P.snap,
  ii  = xknn(P.YY(dims,:),[y1 y2],1);
  y1  = P.YY(dims,ii(1));
  y2  = P.YY(dims,ii(2));
  iy1 = P.YY(idims,ii(1));
  iy2 = P.YY(idims,ii(2));
else
  idims = dims;
  iy1   = y1;
  iy2   = y2;
end;


if P.montage,
  xx = zeros(prod(P.imsize),P.numim);
  for ii=1:P.numim,
    tt=(ii-1)/(P.numim-1);
    yy = iy1*(1-tt)+iy2*tt;
    xx(:,ii) = y2x(yy,P.LX,P.MX,P.PX,P.Pi,...
                   P.LY(idims,:,:),P.MY(idims,:),P.PY(idims,1));
  end;
  rehinton(P.hv,xx,[P.imsize 1 P.numim],P.crange);
  drawnow;
else
  xx = zeros(prod(P.imsize),P.numim);
  for ii=1:P.numim,
    tt=(ii-1)/(P.numim-1);
    yy = iy1*(1-tt)+iy2*tt;
    xx(:,ii) = y2x(yy,P.LX,P.MX,P.PX,P.Pi,...
             P.LY(idims,:,:),P.MY(idims,:),P.PY(idims,1));
  end;
  for jj=1:P.numrep,
    for ii=[1:P.numim P.numim-1:-1:2],
      rehinton(P.hv,xx(:,ii),P.imsize,P.crange);
      drawnow;
      pause(P.delay);
    end;
  end;
end;

set(P.hf,'xdata',[y1(1) y2(1)],'ydata',[y1(2) y2(2)]);
